@@ -178,7 +178,7 @@ fn test() {
                     std::fs::create_dir(&tmp_dir)
                         .expect("can't create a directory for service in tmp");
                     let mut module_path = std::path::PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-                    let mut file_path = std::path::Path::new(file!()).components();
+                    let mut file_path = std::path::Path::new("tests/generation_tests/multi-service-multiple").components();
                     let mut truncated_file_path = Vec::new();
                     loop {
                         if module_path.ends_with(file_path.as_path()) {
@@ -200,7 +200,6 @@ fn test() {
                     for path in truncated_file_path.iter().rev() {
                         module_path.push(path);
                     }
-                    let _ = module_path.pop();
                     let config_path = module_path.join("empty_func/Config.toml");
                     let modules_dir = module_path.join("empty_func/artifacts");
                     let modules_dir = modules_dir
@@ -307,7 +306,6 @@ fn test() {
                     }
                     impl ModuleInterface {
                         pub fn download(&mut self, url: String) -> String {
-                            use std::ops::DerefMut;
                             let arguments = marine_rs_sdk_test::internal::serde_json::json!([url]);
                             let result = self
                                 .marine
@@ -325,7 +323,6 @@ fn test() {
                             url: String,
                             cp: marine_rs_sdk_test::CallParameters
                         ) -> String {
-                            use std::ops::DerefMut;
                             let arguments = marine_rs_sdk_test::internal::serde_json::json!([url]);
                             let result = self
                                 .marine
@@ -362,7 +359,6 @@ fn test() {
                 }
                 impl ModuleInterface {
                     pub fn download(&mut self, url: String) -> String {
-                        use std::ops::DerefMut;
                         let arguments = marine_rs_sdk_test::internal::serde_json::json!([url]);
                         let result = self
                             .marine
@@ -380,7 +376,6 @@ fn test() {
                         url: String,
                         cp: marine_rs_sdk_test::CallParameters
                     ) -> String {
-                        use std::ops::DerefMut;
                         let arguments = marine_rs_sdk_test::internal::serde_json::json!([url]);
                         let result = self
                             .marine
@@ -427,7 +422,7 @@ fn test() {
                     std::fs::create_dir(&tmp_dir)
                         .expect("can't create a directory for service in tmp");
                     let mut module_path = std::path::PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-                    let mut file_path = std::path::Path::new(file!()).components();
+                    let mut file_path = std::path::Path::new("tests/generation_tests/multi-service-multiple").components();
                     let mut truncated_file_path = Vec::new();
                     loop {
                         if module_path.ends_with(file_path.as_path()) {
@@ -449,7 +444,6 @@ fn test() {
                     for path in truncated_file_path.iter().rev() {
                         module_path.push(path);
                     }
-                    let _ = module_path.pop();
                     let config_path = module_path.join("mounted_binary/Config.toml");
                     let modules_dir = module_path.join("mounted_binary/artifacts");
                     let modules_dir = modules_dir
